@@ -14,7 +14,7 @@ author = 'Dustils'
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration
 
 extensions = [
-    'sphinx.ext.autodoc',
+    'sphinx.ext.napoleon',
     'sphinx_rtd_theme',
     'myst_parser',
 ]
